#!/bin/bash
set -o nounset
set -o errexit

# update package tomcat
# usage:
# 1) deploy version to maven:
#    mvn deploy:deploy-file \
#     -DgroupId=org.apache.tomcat \
#     -DartifactId=tomcat \
#     -Dversion=7.0.54 \
#     -Dpackaging=tar.gz \
#     -Dfile=apache-tomcat-7.0.54.tar.gz \
#     -DrepositoryId=archiva.lan.thirdparty \
#     -Durl=http://archiva.office/repository/thirdparty/
# 2) Update the tomcat version in the pom.xml of contentnode-php
# 3) change TOMCAT variable in this script to reflect new version
# 4) add this update script to the changelog: 'update_tomcat.sh'
#

VERSION="6.0.41"
ARCHIVE="tomcat-$VERSION"
TOMCAT="apache-tomcat-$VERSION"

SCRIPT="$(readlink -f $0)"
BASEDIR="$(dirname "$SCRIPT")"

# Check whether the expected updatefile can be found
function checkUpdateFile() {
  if [ -f "$BASEDIR/$ARCHIVE.tar.gz" ]; then
    echo "Found $BASEDIR/$ARCHIVE.tar.gz, starting update"
  else
    echo "Apache Tomcat file $BASEDIR/$ARCHIVE.tar.gz not found, exiting"
    exit 2
  fi
}

# Check whether a update is really needed
function checkUpdate() {
  local installed_version=$(readlink /Node/tomcat | sed 's/.*tomcat-\(.*\)/\1/g')
  local new_version=$(echo -e "$installed_version\n$VERSION" | sort -V | tail -n 1)
  if [[ "$installed_version" == "$new_version" ]] ; then
    echo -e "\n * The currently installed version $installed_version is newer or matches the installer version $VERSION"
    exit 0
  else
    echo -e "\n * The tomcat about to be installed is newer than the installed tomcat. Installation will proceede."
  fi
}

# Update the tomcat and update the symlink
function updateTomcat() {

  if [ -d /Node/$TOMCAT ] ; then
    echo "You already have an $TOMCAT directory. Aborting update. Please update the symlink."
    exit 1
  fi

  echo -e "\n * Stopping possible running tomcat instance"
    /Node/bin/nodectl stop tomcat

  echo -e "\n * Extracting new tomcat version $TOMCAT to /Node"
    tar xzf "$BASEDIR/$ARCHIVE.tar.gz" -C /Node

  echo -e "\n * Adapting new tomcat package"
    rm -rf /Node/$TOMCAT/conf
    rm -rf /Node/$TOMCAT/logs
    rm -rf /Node/$TOMCAT/shared
    rm -rf /Node/$TOMCAT/webapps
    ln -s /Node/etc/tomcat/ /Node/$TOMCAT/conf
    ln -s /Node/var/tomcat/logs/ /Node/$TOMCAT/logs
    ln -s /Node/var/tomcat/shared/ /Node/$TOMCAT/shared
    ln -s /Node/.nodejava/webapps/ /Node/$TOMCAT/webapps

  echo -e "\n * Update permissions and symlink"
    chown -R node: /Node/$TOMCAT

  echo -e "\n * Updating /Node/tomcat symlink"
    rm -f /Node/tomcat
    ln -s /Node/$TOMCAT/ /Node/tomcat

}

echo -e "\n"
echo  "######################################"
echo -e "# GCN Apache Tomcat $VERSION  updater #"
echo  "######################################"
echo -e "\n"

checkUpdateFile
checkUpdate
updateTomcat
